import numpy as np
import pandas as pd
from scipy import stats

class bg_chi:
  def __init__(self, x, y):
    self.x = x
    self.y = y
    self.table=pd.crosstab(self.x,self.y) 
    self.chi2,self.p,self.dof,self.exp=stats.chi2_contingency(self.table)
    self.exp_table=pd.DataFrame(self.exp, columns = self.table.columns, index=self.table.index)
  def expected(self):
    return (self.exp_table)
  def chivalue(self):
    return self.chi2
  def pvalue(self):
    return self.p
  def degreeoffreedom(self):
    return self.dof


from setuptools import setup, find_packages
import codecs
import os

VERSION='0.0.1'
DESCRIPTION='Chi sqaure applied to use directly'
LONG_DESCRIPTION='A basic hello package long desc'

setup(name='bhargabchi',
      packages = find_packages(),
      version=VERSION,
      description=DESCRIPTION,

      author='Bhargab',
      author_email='bhargab.ganguli@gmail.com',
      keywords = ['chi2', 'dof', 'exp', 'exp_table', 'p', 'pvalue', 'expected', 'degreeoffreedom', 'chivalue'],
      license='MIT', #YOUR LICENSE HERE!

      install_requires=['scipy','pandas', 'numpy'],  #YOUR DEPENDENCIES HERE
  

      classifiers=[
        'Development Status :: 3 - Alpha',      # "3 - Alpha", "4 - Beta" or "5 - Production/Stable"
        'Intended Audience :: Developers',      
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License', # Your License Here  
        'Programming Language :: Python :: 3',    # List Python versions that you support Here  
        ],
)